import requests
from requests import Response


def generate_token(url: str, username: str, password: str) -> Response:
    """
    Generate access token and refresh token from username and password.
    Refresh token can be used later to generate new access token.

    :param url: str base url to AI Core
    :param username: user's username in AI Core
    :param password: user's password to AI Core
    :return: Response from AI Core
    """
    credentials = dict(username=username, password=password)
    return requests.post(f'{url}/token/', json=credentials)


def generate_token_from_refresh_token(url: str, token: str) -> Response:
    """
    Takes a refresh type JSON web token and returns an access type JSON web token if the refresh token is valid.

    :param url: base url to AI Core as string
    :param token: token generated by user with username and password
    :return: response from AI Core
    """
    return requests.post(f'{url}/token/refresh/', json={'refresh': token})


def verify_token(url: str, token: str) -> Response:
    """
    Check if token is valid.

    :param url: base url to AI Core as string
    :param token: token which user would like to verify
    :return: response from AI Core
    """
    return requests.post(f'{url}/token/verify/', json={'token': token})
